# @summary handle settings of .env
#
# @param db_database name of PostgreSQL database used to store data
# @param db_host host to use to connect to the PostgreSQL database
# @param db_username PostgreSQL user name used to to connect to the PostgreSQL database
# @param db_password password of the PostgreSQL user.
# @param db_pool
#        maximum number of connections the pool may manage.
#        https://api.rubyonrails.org/classes/ActiveRecord/ConnectionAdapters/ConnectionPool.html
#
type Demarchessimplifiees::Config = Struct[{
  app_host                           => String[1],
  secret_key_base                    => String[1],
  signing_key                        => String[1],
  saml_idp_certificate               => String[1],
  saml_idp_secret_key                => String[1],
  sendinblue_login_url               => Stdlib::HTTPSUrl,
  db_database                        => String[1],
  db_host                            => Stdlib::Host,
  db_username                        => String[1],
  db_password                        => String[1],
  db_pool                            => Integer,
  fog_openstack_api_key              => String,
  fog_openstack_username             => String,
  fog_openstack_url                  => Variant[String[0,0],Stdlib::HTTPUrl],
  fog_openstack_region               => String,
  fog_enabled                        => Boolean,
  ds_proxy_url                       => Variant[String[0,0],Stdlib::HTTPUrl],
  fc_particulier_id                  => String,
  fc_particulier_secret              => String,
  fc_particulier_base_url            => Variant[String[0,0],Stdlib::HTTPUrl],
  otp_secret_key                     => String[32],
  helpscout_mailbox_id               => String,
  helpscout_client_id                => String,
  helpscout_client_secret            => String,
  helpscout_webhook_secret           => String,
  matomo_enabled                     => Boolean,
  matomo_id                          => Integer,
  sendinblue_balancing               => String,
  sendinblue_balancing_value         => String,
  sendinblue_enabled                 => Boolean,
  sendinblue_client_key              => String,
  sendinblue_smtp_key                => String,
  sendinblue_user_name               => String,
  mailjet_api_key                    => String,
  mailjet_secret_key                 => String,
  api_entreprise_key                 => String,
  trusted_networks                   => Array,
  api_adresse_url                    => Stdlib::HTTPUrl,
  api_geo_url                        => Stdlib::HTTPUrl,
  api_education_url                  => Stdlib::HTTPUrl,
  max_attempts_jobs                  => Integer,
  application_name                   => Optional[String[1]],
  application_shortname              => Optional[String[1]],
  application_base_url               => Optional[Stdlib::HTTPUrl],
  ds_env                             => Optional[String[1]],
  contact_email                      => Optional[String[1]],
  equipe_email                       => Optional[String[1]],
  tech_email                         => Optional[String[1]],
  no_reply_email                     => Optional[String[1]],
  old_contact_email                  => Optional[String[1]],
  contact_phone                      => Optional[String[1]],
  contact_address                    => Optional[String[1]],
  accessibilite_url                  => Optional[Stdlib::HTTPUrl],
  status_page_url                    => Optional[Stdlib::HTTPUrl],
  france_connect_enabled             => Optional[Boolean],
  demande_inscription_admin_page_url => Optional[Stdlib::HTTPUrl],
  doc_url                            => Optional[Stdlib::HTTPUrl],
  faq_url                            => Optional[Stdlib::HTTPUrl],
  cgu_url                            => Optional[Stdlib::HTTPUrl],
  mentions_legales_url               => Optional[Stdlib::HTTPUrl],
  procedure_default_logo_src         => Optional[String[1]],
  favicon_16px_src                   => Optional[String[1]],
  favicon_32px_src                   => Optional[String[1]],
  favicon_96px_src                   => Optional[String[1]],
  header_logo_src                    => Optional[String[1]],
  header_logo_alt                    => Optional[String[1]],
  header_logo_width                  => Optional[Integer],
  header_logo_height                 => Optional[Integer],
  mailer_logo_src                    => Optional[String[1]],
  mailer_footer_logo_src             => Optional[String[1]],
  watermark_file                     => Optional[String[1]],
  dossier_pdf_export_logo_src        => Optional[String[1]],
}]
